summaryrefslogtreecommitdiff
path: root/power/baytrail.c
diff options
context:
space:
mode:
Diffstat (limited to 'power/baytrail.c')
-rw-r--r--power/baytrail.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/power/baytrail.c b/power/baytrail.c
index 5349045520..d4c5fb1d1a 100644
--- a/power/baytrail.c
+++ b/power/baytrail.c
@@ -268,10 +268,10 @@ enum power_state power_handle_state(enum power_state state)
disable_sleep(SLEEP_MASK_AP_RUN);
/*
* Wait 5 ms after all voltages good. 100 ms is only needed
* for PCIe devices; mini-PCIe devices should need only 1 ms.
*/
- msleep(5);
+ msleep(15);
/*
* Throttle CPU if necessary. This should only be asserted
@@ -268,10 +268,10 @@ enum power_state power_handle_state(enum power_state state)
disable_sleep(SLEEP_MASK_AP_RUN);
/*
- * Wait 5 ms after all voltages good. 100 ms is only needed
- * for PCIe devices; mini-PCIe devices should need only 1 ms.
+ * Wait 15 ms after all voltages good. 100 ms is only needed
+ * for PCIe devices; mini-PCIe devices should need only 10 ms.
*/